pub struct VersionedApp {
pub version: u32,
pub wasm_hash: B32,
}Expand description
Identifies a specific version of an app’s Wasm binary, signed by the app’s owning key.
For a versioned app, the app’s vk is the SHA256 of a public key. The corresponding
AppSignature proves that the holder of that key has authorized this particular Wasm
binary as the given version of the app.
Fields
version: u32Version number, as exposed by the __app_version export of the Wasm binary.
wasm_hash: B32SHA256 hash of the Wasm binary that implements this version of the app.